TranslucentRippleButton class

Inheritance

Constructors

TranslucentRippleButton({required dynamic onPressed()?, required bool isEnabled, required String text, required RippleButtonStyle style, required RippleButtonColor color, required RippleButtonBorder border, required Color background, Widget? icon})

Properties

background → Color
final
border → RippleButtonBorder
RippleButtonColor expects border attributes for the ripple button. Note: Not all colors can be since is a preset button
final
color → RippleButtonColor
RippleButtonColor expects colors attributes for the ripple button. Note: Not all colors can be since is a preset button
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
Widget expects an icon or image icon to show before the button text. Optional, if not provided, only shows text
final
isEnabled → bool
isEnabled expects a boolean This will enable or disable button
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed → dynamic Function()?
onPressed expects a function that will be executed on button press.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → RippleButtonStyle
RippleButtonStyle expects styles attributes for the ripple button. Note: Not all styles can be since is a preset button
final
text → String
text expects a String that will be show inside the button
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited